# kwil.py

[![PyPI - Version](https://img.shields.io/pypi/v/kwil.svg)](https://pypi.org/project/kwil)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kwil.svg)](https://pypi.org/project/kwil)

Borrows heavily from [web3.py](https://github.com/ethereum/web3.py)

-----

Check [quickstart](./docs/quickstart.md) to get started.


## License

MIT